use tauri::{
    AppHandle,
    CustomMenuItem,
    Manager,
    SystemTray,
    SystemTrayEvent,
    SystemTrayMenu,
    async_runtime as rt,
};

use crate::app;
use crate::state::AppState;


pub fn create() -> SystemTray {
    let show = CustomMenuItem::new("show_hide".to_string(), "Show");
    let quit = CustomMenuItem::new("exit".to_string(), "Exit");

    let menu = SystemTrayMenu::new()
        .add_item(show)
        .add_item(quit);

    SystemTray::new().with_menu(menu)
}


pub fn handle_event(app_handle: &AppHandle, event: SystemTrayEvent) {
    match event {
        SystemTrayEvent::MenuItemClick{ id, .. } => {
            match id.as_str() {
                "exit" => app_handle.exit(0),
                "show_hide" => {
                    let _ = app::toggle_main_window(app_handle);
                    let new_handle = app_handle.app_handle();
                    rt::spawn(async move {
                        let state = new_handle.state::<AppState>();
                        state.signal_activity().await;
                    });
                }
                _ => (),
            }
        }
        _ => (),
    }
}
